@@ -255,15 +255,24 @@ class Recipe(Scripts):
         """Write original pkg_resources.py file from setuptools egg."""
         setuptools_eggs = [e for e in ws.entries if rx_setuptools.match(e)]
         assert len(setuptools_eggs) == 1, "setuptools not found"
-        if os.path.isdir(setuptools_eggs[0]):
-            src = os.path.join(setuptools_eggs[0], 'pkg_resources.py')
-            dst = os.path.join(d, 'pkg_resources.py')
-            shutil.copyfile(src, dst)
+        eggs_path = setuptools_eggs[0]
+        if os.path.isdir(eggs_path):
+            for root, dirs, files in os.walk(eggs_path):
+                for file_ in files:
+                    fn = os.path.join(root, file_)
+                    if 'pkg_resources' in fn:
+                        sub = root[len(eggs_path) + 1:]
+                        dest = os.path.join(d, sub)
+                        try:
+                            os.makedirs(dest)
+                        except OSError:
+                            pass
+                        shutil.copy(fn, dest)
         else:
             egg_contents = zipfile.ZipFile(setuptools_eggs[0])
-            pkg_resources = open(os.path.join(d, 'pkg_resources.py'), "w")
-            pkg_resources.write(egg_contents.read('pkg_resources.py'))
-            pkg_resources.close()
+            for n in egg_contents.namelist():
+                if n.startswith('pkg_resources'):
+                    egg_contents.extract(n, path=d)
 
     def copy_packages(self, ws, lib):
         """Copy egg contents to lib-directory."""
